<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>NetFileChooseEdit</name>
    <message>
        <source>All files (*)</source>
        <translation>усі файли (*)</translation>
    </message>
</context>
<context>
    <name>NetPasswordEdit</name>
    <message>
        <source>Required</source>
        <translation>Обов&apos;язкове</translation>
    </message>
</context>
<context>
    <name>PageAirplane</name>
    <message>
        <source>Airplane mode</source>
        <translation>Режим польоту</translation>
    </message>
    <message>
        <source>Stop wireless communication</source>
        <translation>Припинити бездротовий обмін даними</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation>Вмикання режиму польоту вимикає бездротову мережу, особистку точку доступу та Bluetooth</translation>
    </message>
</context>
<context>
    <name>PageAppProxy</name>
    <message>
        <source>Application Proxy</source>
        <translation>Проксі для програм</translation>
    </message>
    <message>
        <source>Set up proxy servers</source>
        <translation>Налаштувати проксі-сервери</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Тип проксі</translation>
    </message>
    <message>
        <source>http</source>
        <translation>http</translation>
    </message>
    <message>
        <source>socks4</source>
        <translation>socks4</translation>
    </message>
    <message>
        <source>socks5</source>
        <translation>socks5</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP-адреса</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Обов&apos;язкове</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Некоректна IP-адреса</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Порт</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Некоректний порт</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Користувач</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Необов&apos;язкове</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Позначте пункт «Використовувати проксі» у контекстному меню програми у Launcher після налаштовування</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
</context>
<context>
    <name>PageDSL</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>Set up a dial-up network connection</source>
        <translation>Налаштувати комутоване з&apos;єднання з мережею</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Відʼєднатися</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>З&apos;єднатися</translation>
    </message>
    <message>
        <source>Add PPPoE connection</source>
        <translation>Додати PPPoE-з&apos;єднання</translation>
    </message>
</context>
<context>
    <name>PageDSLSettings</name>
    <message>
        <source> Network Properties</source>
        <translation>Властивості мережі</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Ви справді хочете вилучити це налаштування?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
</context>
<context>
    <name>PageDetails</name>
    <message>
        <source>Network Details</source>
        <translation>Параметри мережі</translation>
    </message>
    <message>
        <source>View all network configurations</source>
        <translation>Переглянути усі налаштування мережі</translation>
    </message>
    <message>
        <source>Details has been copied</source>
        <translation>Параметри скопійовано</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Позначити усе</translation>
    </message>
    <message>
        <source>Network Detection</source>
        <translation>Виявлення мережі</translation>
    </message>
</context>
<context>
    <name>PageHotspot</name>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>Особистий WPA/WPA2</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>Особистий WPA3</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Немає</translation>
    </message>
    <message>
        <source>2.4 GHz</source>
        <translation>2,4 ГГц</translation>
    </message>
    <message>
        <source>5 GHz</source>
        <translation>5 ГГц</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Авто</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Не прив&apos;язано</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Особиста точка доступу</translation>
    </message>
    <message>
        <source>Share the network</source>
        <translation>Поділитися мережею</translation>
    </message>
    <message>
        <source>My Hotspot</source>
        <translation>Ваша точка доступу</translation>
    </message>
    <message>
        <source>Edit My Hotspot</source>
        <translation>Редагувати вашу точку доступу</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Назва (SSID)</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Обов&apos;язкове</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Захист</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Смуга</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <source>Shared Settings</source>
        <translation>Спільні параметри</translation>
    </message>
    <message>
        <source>Hotspot Sharing Device</source>
        <translation>Пристрій оприлюднення точки доступу</translation>
    </message>
    <message>
        <source>If you want to use the personal hotspot, disable Airplane Mode first and then enable the wireless network adapter.</source>
        <translation>Якщо ви хочете скористатися особистою точкою доступу, спочатку вимкніть режим польоту, а потім увімкніть бездротовий мережевий адаптер.</translation>
    </message>
    <message>
        <source>If you want to use the personal hotspot, disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first and then enable the wireless network adapter.</source>
        <translation>Якщо ви хочете скористатися особистою точкою доступу, спочатку вимкніть &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;режим польоту&lt;/a&gt;, а потім увімкніть бездротовий мережевий адаптер.</translation>
    </message>
</context>
<context>
    <name>PageSettings</name>
    <message>
        <source> Network Properties</source>
        <translation>Властивості мережі</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Ви справді хочете вилучити це налаштування?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
</context>
<context>
    <name>PageSystemProxy</name>
    <message>
        <source>System Proxy</source>
        <translation>Загальносистемний проксі</translation>
    </message>
    <message>
        <source>Set up proxy servers</source>
        <translation>Налаштувати проксі-сервери</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Тип проксі</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Авто</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Вручну</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Адреса налаштувань</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Обов&apos;язкове</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP-проксі</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS-проксі</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP-проксі</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS-проксі</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Ігнорувати налаштування проксі для зазначених вище вузлів і доменів</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
</context>
<context>
    <name>PageVPN</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Connect, add, import</source>
        <translation>З&apos;єднання, додавання, імпортування</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Відʼєднатися</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>З&apos;єднатися</translation>
    </message>
    <message>
        <source>Add VPN</source>
        <translation>Додати VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Імпортувати VPN</translation>
    </message>
    <message>
        <source>*.conf</source>
        <translation>*.conf</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Помилка імпортування</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Помилка під час роботи з файлами</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Гаразд</translation>
    </message>
</context>
<context>
    <name>PageVPNSettings</name>
    <message>
        <source> Network Properties</source>
        <translation>Властивості мережі</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>Тип VPN</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Ви справді хочете вилучити це налаштування?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Експортувати</translation>
    </message>
    <message>
        <source>*.conf</source>
        <translation>*.conf</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
</context>
<context>
    <name>PageWiredDevice</name>
    <message>
        <source>Connect, edit network settings</source>
        <translation>З&apos;єднання, редагування параметрів мережі</translation>
    </message>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Спочатку, вставте кабель мережі</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Відʼєднатися</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>З&apos;єднатися</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Додати мережеве з&apos;єднання</translation>
    </message>
</context>
<context>
    <name>PageWirelessDevice</name>
    <message>
        <source>Connect, edit network settings</source>
        <translation>З&apos;єднання, редагування параметрів мережі</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Відʼєднатися</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>З&apos;єднатися</translation>
    </message>
    <message>
        <source>My Networks</source>
        <translation>Ваші мережі</translation>
    </message>
    <message>
        <source>Other Networks</source>
        <translation>Інші мережі</translation>
    </message>
    <message>
        <source>Disable Airplane Mode first if you want to connect to a wireless network</source>
        <translation>Спочатку вимкніть точку доступу, якщо ви хочете з&apos;єднатися із бездротовою мережею</translation>
    </message>
    <message>
        <source>Disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Якщо ви хочете встановити з&apos;єднання з бездротовою мережею, спочатку вимкніть &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Режим польоту&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Спочатку вимкніть точку доступу, якщо ви хочете з&apos;єднатися із бездротовою мережею</translation>
    </message>
    <message>
        <source>&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;Disable hotspot&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Якщо ви хочете з&apos;єднатися із бездротовою мережею, &lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;вимкніть точку доступу&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>SectionDNS</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Виконано</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Змінити</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Некоректна IP-адреса</translation>
    </message>
</context>
<context>
    <name>SectionDevice</name>
    <message>
        <source>Not Bind</source>
        <translation>Не прив&apos;язано</translation>
    </message>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>MAC-адреса пристрою</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Клонована MAC-адреса</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Налаштувати MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Смуга</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Авто</translation>
    </message>
    <message>
        <source>2.4 GHz</source>
        <translation>2,4 ГГц</translation>
    </message>
    <message>
        <source>5 GHz</source>
        <translation>5 ГГц</translation>
    </message>
</context>
<context>
    <name>SectionGeneric</name>
    <message>
        <source>General</source>
        <translation>Загальне</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Назва (SSID)</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Назва</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Обов&apos;язкове</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Автоматичне з&apos;єднання</translation>
    </message>
</context>
<context>
    <name>SectionIPv4</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Виконано</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Змінити</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Вимкнено</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Вручну</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Авто</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Метод</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Використовується тільки у відповідних ресурсах</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP-адреса</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Некоректна IP-адреса</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Маска мережі</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Шлюз</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Некоректна маска мережі</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Некоректний шлюз</translation>
    </message>
    <message>
        <source>Duplicate IP address</source>
        <translation>Дублювання IP-адреси</translation>
    </message>
</context>
<context>
    <name>SectionIPv6</name>
    <message>
        <source>Disabled</source>
        <translation>Вимкнено</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Вручну</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ігнорувати</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Авто</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Виконано</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Змінити</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Метод</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Використовується тільки у відповідних ресурсах</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP-адреса</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Некоректна IP-адреса</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Префікс</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Шлюз</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Некоректна маска мережі</translation>
    </message>
    <message>
        <source>Duplicate IP address</source>
        <translation>Дублювання IP-адреси</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Некоректний шлюз</translation>
    </message>
</context>
<context>
    <name>SectionPPP</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Використати MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-бітове MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE з контролем стану</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Забороняти EAP-розпізнавання</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Забороняти PAP-розпізнавання</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Забороняти CHAP-розпізнавання</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Забороняти MSCHAP-розпізнавання</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Забороняти MSCHAPv2-розпізнавання</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Без стискання даних BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Без стискання даних Deflate</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Без стискання  заголовків TCP</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Надсилати луна-пакети PPP</translation>
    </message>
</context>
<context>
    <name>SectionPPPOE</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Користувач</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Обов&apos;язкове</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Служба</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
</context>
<context>
    <name>SectionSecret</name>
    <message>
        <source>Security</source>
        <translation>Захист</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Тунельований TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Захищений EAP</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>GTC</source>
        <translation>GTC</translation>
    </message>
    <message>
        <source>MSCHAPV2</source>
        <translation>MSCHAPV2</translation>
    </message>
    <message>
        <source>PAP</source>
        <translation>PAP</translation>
    </message>
    <message>
        <source>MSCHAP</source>
        <translation>MSCHAP</translation>
    </message>
    <message>
        <source>CHAP</source>
        <translation>CHAP</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Немає</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>Особистий WPA/WPA2</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>Промислова WPA/WPA2</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>Особистий WPA3</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP-розпізнавання</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Профіль</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Обов&apos;язкове</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Параметри pwd</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Зберегти пароль для цього користувача</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Зберігати паролі для усіх користувачів</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Завжди питати</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Ключ</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Приватний pwd</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Розпізнавання</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Спільний ключ</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Відкрита система</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Закритий ключ</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Анонімний ідентифікатор</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Передбачення</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Вимкнено</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Анонімно</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Розпізнано</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Обидва</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC-файл</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Сертифікат CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Сертифікат користувача</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP-версія</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Автоматично</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Версія 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Версія 1</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Внутрішнє розпізнавання</translation>
    </message>
</context>
<context>
    <name>SectionVPN</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>усі файли (*)</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Обов&apos;язкове</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Некоректний шлюз</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Шлюз</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Сертифікат CA</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Проксі</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Дозволити Cisco Secure Desktop Trojan</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>Сценарій CSD</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Тип розпізнавання</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Закритий ключ</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH-агент</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Смарт-картка</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Попередньо поширений ключ</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Сертифікат користувача</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Користувач</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Використовувати FSID для пароля до ключа</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Сертифікати (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Сертифікати з паролем (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Статичний ключ</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Параметри pwd</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Збережено</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Запитати</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Не є обов&apos;язковим</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Приватний pwd</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Налаштувати напрямок ключа</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Напрямок ключа</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>Віддалений IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>Локальний IP</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>Домен NT</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Запит внутрішньої IP-адреси</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Забезпечити інкапсуляцію UDP</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Використовувати стиснення IP</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Увімкнути нетипові варіанти шифрування</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Назва групи</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Груповий пароль</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Використати гібридне розпізнавання</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>Файл CA</translation>
    </message>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Використати MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Захист</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Усі доступні (типове)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-бітове (менш безпечне)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-бітове (найбезпечніше)</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE з контролем стану</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Забороняти EAP-розпізнавання</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Забороняти PAP-розпізнавання</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Забороняти CHAP-розпізнавання</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Забороняти MSCHAP-розпізнавання</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Забороняти MSCHAPv2-розпізнавання</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Без стискання даних BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Без стискання даних Deflate</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Без стискання  заголовків TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Без стискання полів протоколів</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Без стискання адреси/керування</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Надсилати луна-пакети PPP</translation>
    </message>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Увімкнути IPsec</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>Ідентифікатор групи</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Алгоритми Фази1</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Алгоритми Фази2</translation>
    </message>
    <message>
        <source>VPN Advanced</source>
        <translation>Розширений VPN</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Налаштувати порт шлюзу</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Порт шлюзу</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Налаштувати інтервал повторного узгодження</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Інтервал повторного узгодження</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Використати стиснення файлів LZO</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Використати зв‘язок TCP</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Використати пристрій TAP</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Налаштувати тунель MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Налаштувати розмір фрагмента UDP</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>Розмір фрагмента UDP</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Обмежити Tunnel TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Розмістити у випадковому порядку віддалені вузли</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Домен</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Постачальник</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (типове)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Мережевий екран</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Версія</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Шифрування</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Захищене (типовий)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Слабке</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Немає</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>Обхідний режим NAT</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T, коли доступно (типове)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>Завжди NAT-T</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Вимкнено</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>Група обробки даних IKE</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>Група DH 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>Група DH 2 (типово)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>Група DH 5</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Розповсюдити конфіденційність</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Сервер (типова)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>Група DH 2</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Локальний порт</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Вимкнути виявлення непрацездатних однорангових пристроїв</translation>
    </message>
    <message>
        <source>VPN Security</source>
        <translation>Захист VPN</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Шифр</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Типове</translation>
    </message>
    <message>
        <source>DES-CBC</source>
        <translation>DES-CBC</translation>
    </message>
    <message>
        <source>RC2-CBC</source>
        <translation>RC2-CBC</translation>
    </message>
    <message>
        <source>DES-EDE-CBC</source>
        <translation>DES-EDE-CBC</translation>
    </message>
    <message>
        <source>DES-EDE3-CBC</source>
        <translation>DES-EDE3-CBC</translation>
    </message>
    <message>
        <source>DESX-CBC</source>
        <translation>DESX-CBC</translation>
    </message>
    <message>
        <source>BF-CBC</source>
        <translation>BF-CBC</translation>
    </message>
    <message>
        <source>RC2-40-CBC</source>
        <translation>RC2-40-CBC</translation>
    </message>
    <message>
        <source>CAST5-CBC</source>
        <translation>CAST5-CBC</translation>
    </message>
    <message>
        <source>RC2-64-CBC</source>
        <translation>RC2-64-CBC</translation>
    </message>
    <message>
        <source>AES-128-CBC</source>
        <translation>AES-128-CBC</translation>
    </message>
    <message>
        <source>AES-192-CBC</source>
        <translation>AES-192-CBC</translation>
    </message>
    <message>
        <source>AES-256-CBC</source>
        <translation>AES-256-CBC</translation>
    </message>
    <message>
        <source>CAMELLIA-128-CBC</source>
        <translation>CAMELLIA-128-CBC</translation>
    </message>
    <message>
        <source>CAMELLIA-192-CBC</source>
        <translation>CAMELLIA-192-CBC</translation>
    </message>
    <message>
        <source>CAMELLIA-256-CBC</source>
        <translation>CAMELLIA-256-CBC</translation>
    </message>
    <message>
        <source>SEED-CBC</source>
        <translation>SEED-CBC</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC Auth</translation>
    </message>
    <message>
        <source>RSA MD-4</source>
        <translation>RSA MD-4</translation>
    </message>
    <message>
        <source>MD-5</source>
        <translation>MD-5</translation>
    </message>
    <message>
        <source>SHA-1</source>
        <translation>SHA-1</translation>
    </message>
    <message>
        <source>SHA-224</source>
        <translation>SHA-224</translation>
    </message>
    <message>
        <source>SHA-256</source>
        <translation>SHA-256</translation>
    </message>
    <message>
        <source>SHA-384</source>
        <translation>SHA-384</translation>
    </message>
    <message>
        <source>SHA-512</source>
        <translation>SHA-512</translation>
    </message>
    <message>
        <source>RIPEMD-160</source>
        <translation>RIPEMD-160</translation>
    </message>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN-проксі</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Тип проксі</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP сервера</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Порт</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>У разі збою повторювати спроби нескінченно</translation>
    </message>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>TLS-розпізнавання у VPN</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Збіг теми</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Тип віддаленого сертифіката</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Клієнт</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Сервер</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Файл ключа</translation>
    </message>
</context>
<context>
    <name>SystemProxyConfigItem</name>
    <message>
        <source>Optional</source>
        <translation>Необов&apos;язкове</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Порт</translation>
    </message>
    <message>
        <source>Authentication is required</source>
        <translation>Слід пройти розпізнавання</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Користувач</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Обов&apos;язкове</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
</context>
<context>
    <name>dde::network::NetAirplaneModeTipsItem</name>
    <message>
        <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Якщо ви хочете встановити з&apos;єднання з бездротовою мережею, спочатку вимкніть &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Режим польоту&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerPrivate</name>
    <message>
        <source>IP conflict</source>
        <translation>Конфлікт IP</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Мережа</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerThreadPrivate</name>
    <message>
        <source>Wired Connection %1</source>
        <translation>Дротове з&apos;єднання %1</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>З&apos;єднання PPPoE %1</translation>
    </message>
    <message>
        <source>Connecting &quot;%1&quot;</source>
        <translation>Встановлюємо з&apos;єднання із «%1»</translation>
    </message>
    <message>
        <source>&quot;%1&quot; connected</source>
        <translation>З&apos;єднання із «%1» встановлено</translation>
    </message>
    <message>
        <source>&quot;%1&quot; disconnected</source>
        <translation>З&apos;єднання із «%1» розірвано</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
        <translation>Не вдалося з&apos;єднатися із «%1». Будь ласка, перевірте, чи працює ваш маршрутизатор або мережевий кабель.</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
        <translation>Не вдалося встановити з&apos;єднання із «%1». Будь ласка, підійдіть ближче до бездротового маршрутизатора.</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
        <translation>Не вдалося встановити з&apos;єднання із «%1». Вказано помилковий пароль.</translation>
    </message>
    <message>
        <source>Password is required to connect &quot;%1&quot;</source>
        <translation>Для встановлення з&apos;єднання із «%1» потрібен пароль</translation>
    </message>
    <message>
        <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
        <translation>Не вдалося знайти мережу WLAN 802.11 «%1»</translation>
    </message>
    <message>
        <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
        <translation>Для встановлення з&apos;єднання з «%1», будь ласка, налаштуйте ваші дані для розпізнавання після входу до системи</translation>
    </message>
</context>
<context>
    <name>dde::network::NetSystemProxyControlItem</name>
    <message>
        <source>System Proxy</source>
        <translation>Загальносистемний проксі</translation>
    </message>
</context>
<context>
    <name>dde::network::NetVPNTipsItem</name>
    <message>
        <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
        <translation>Налаштування VPN не призвели до з&apos;єднання або з&apos;єднання не вдалося встановити. Будь ласка, &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;перейдіть до «Центру керування»&lt;/a&gt;, щоб перевірити, чи усе налаштовано правильно.</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWiredControlItem</name>
    <message>
        <source>Wired Network</source>
        <translation>Дротова мережа</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessControlItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Бездротова мережа</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessHiddenItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Встановлення з&apos;єднання із прихованою мережею</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessMineItem</name>
    <message>
        <source>My Networks</source>
        <translation>Мої мережі</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessOtherItem</name>
    <message>
        <source>Other Networks</source>
        <translation>Інші мережі</translation>
    </message>
</context>
<context>
    <name>network</name>
    <message>
        <source>Network</source>
        <translation>Мережа</translation>
    </message>
</context>
</TS>